library routes_transition_jr;

import 'package:flutter/material.dart';

/// Tipos de animaciones
enum AnimationType { normal, fadeIn }

/// Main class [context] es el BuildContext de la aplicacion en ese momento.
/// [child] es la pagina donde se realizara la navegacion.
/// [animation] es la animacion que se ejecutara al realizar el cambio de pagina.
/// [duration] es el tiempo que tarda la animacion en ejecutarse.
/// [replacement] es el tipo de entrada de la pagina, con retorno o sin retorno
class RouteTransationJr {
  final BuildContext context;
  final Widget child;
  final AnimationType animation;
  final Duration duration;
  final bool replacement;

  RouteTransationJr(
      {required this.context,
      required this.child,
      this.animation = AnimationType.normal,
      this.duration = const Duration(milliseconds: 300),
      this.replacement = false}) {
    switch (animation) {
      case AnimationType.normal:
        _normalTransition();
        break;
      case AnimationType.fadeIn:
        _fadeInTransition();
        break;
    }
  }

  /// Push normal de la pagina
  void _pushPage(Route route) => Navigator.push(context, route);

  /// push de la pagina con relacement, para quitar el retorno
  void _pushReplacementPage(Route route) =>
      Navigator.pushReplacement(context, route);

  /// Trancición normal de flutter
  void _normalTransition() {
    final route = MaterialPageRoute(builder: (_) => child);
    (replacement) ? _pushReplacementPage(route) : _pushPage(route);
  }

  /// Trancición personalizada fadeIn para el cambio de pagina
  void _fadeInTransition() {
    final route = PageRouteBuilder(
        pageBuilder: (_, __, ___) => child,
        transitionDuration: duration,
        transitionsBuilder: (_, animation, __, child) {
          return FadeTransition(
            child: child,
            opacity: Tween<double>(begin: 0.0, end: 1.0).animate(
              CurvedAnimation(parent: animation, curve: Curves.easeOut),
            ),
          );
        });
    (replacement) ? _pushReplacementPage(route) : _pushPage(route);
  }
}
